@@ -1,30 +1,34 @@
-# $Id: errnolist.sh,v 3.0 1993/08/18 12:04:36 ram Exp $
+# $Id: errnolist.sh,v 3.0.1.1 1994/01/24 14:00:00 ram Exp ram $
 #
-#  Copyright (c) 1991-1993, Raphael Manfredi
+#  Copyright (c) 1991-1997, 2004-2006, Raphael Manfredi
 #  
 #  You may redistribute only under the terms of the Artistic Licence,
 #  as specified in the README file that comes with the distribution.
 #  You may reuse parts of this distribution only within the terms of
 #  that same Artistic Licence; a copy of which may be found at the root
-#  of the source tree for dist 3.0.
+#  of the source tree for dist 4.0.
 #
 # Original Author: Harlan Stenn <harlan@mumps.pfcs.com>
 #
 # $Log: errnolist.sh,v $
+# Revision 3.0.1.1  1994/01/24  14:00:00  ram
+# patch16: changed top ln-style config.sh lookup into test-style one
+#
 # Revision 3.0  1993/08/18  12:04:36  ram
 # Baseline for dist 3.0 netwide release.
 #
 
 case $CONFIG in
 '')
-	if test ! -f config.sh; then
-		ln ../config.sh . || \
-		ln ../../config.sh . || \
-		ln ../../../config.sh . || \
-		ln ../../../../config.sh . || \
-		(echo "Can't find config.sh."; exit 1)
-	fi 2>/dev/null
-	. ./config.sh
+	if test -f config.sh; then TOP=.;
+	elif test -f ../config.sh; then TOP=..;
+	elif test -f ../../config.sh; then TOP=../..;
+	elif test -f ../../../config.sh; then TOP=../../..;
+	elif test -f ../../../../config.sh; then TOP=../../../..;
+	else
+		echo "Can't find config.sh."; exit 1
+	fi
+	. $TOP/config.sh
 	;;
 esac
 case "$0" in
