@@ -1,4 +1,4 @@
-;# $Id: order.pl 1 2006-08-24 12:32:52Z rmanfredi $
+;# $Id$
 ;#
 ;#  Copyright (c) 1991-1997, 2004-2006, Raphael Manfredi
 ;#  
@@ -33,7 +33,7 @@ sub solve_dependencies {
 			# Ignore conditional symbol request
 		} else {
 			chop;
-			system;
+			system $_;
 		}
 	}
 	chdir($WD) || die "Can't chdir to $WD: $!.\n";
