@@ -1,4 +1,4 @@
-;# $Id: xref.pl 1 2006-08-24 12:32:52Z rmanfredi $
+;# $Id$
 ;#
 ;#  Copyright (c) 1991-1997, 2004-2006, Raphael Manfredi
 ;#  
@@ -55,6 +55,9 @@ sub p_wanted {
 		$cwanted{$_} = "$fake";					# Attached to this symbol
 		push(@Master, "?$unit:$fake=''");		# Fake initialization
 	}
+
+	delete @cmaster{keys %excluded_symbol};
+	delete @cwanted{keys %excluded_symbol};
 }
 
 # Ingnore the following:
